# tisch.py

from grafikfenster import *
from math import radians
from moebel import Moebel

### ---------------------------------------------------
class Tisch(Moebel):
    """Klasse Tisch
    ermoeglicht das Zeichnen und Bearbeiten eines
    Tisch-Symbols fuer den Raumplaner"""

    def __init__(self,
                 xPos=60,
                 yPos=10,
                 breite=120,
                 tiefe=60,
                 winkel=0,
                 farbe='red',
                 sichtbar=False):
        """Konstruktor mit vordefinierten Parametern
        Konstruktor der Oberklasse aufrufen!"""
        Moebel.__init__(self, xPos, yPos, breite, tiefe, winkel, farbe, sichtbar)
        
    def GibFigur(self):
        """definiert und transformiert die zu zeichnende Figur"""
        gc = Zeichenflaeche.GibZeichenflaeche().GibGC()
        path = gc.CreatePath()
        
        # Hilfsvariable zur Vereinfachung
        b,t = self.GibBreite(), self.GibTiefe()
        path.AddRectangle(0, 0, b, t)
        
        x,y,w = self.GibX(), self.GibY(), self.GibWinkel()
        gc.PushState()
        gc.Translate(x+b/2, y+t/2)
        gc.Rotate(radians(w))
        gc.Translate(-b/2, -t/2)
        transformation = gc.GetTransform()
        gc.PopState()
        path.Transform(transformation)
        return path


### ---------------------------------------------------
class TischApp(wx.App):
    """Test-Anwendung speziell fuer Tisch"""
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        #self.fenster.ZeigeFillingFrame()
        self.TestAnwendung()
        return True

    def TestAnwendung(self):
        """Allein fuer die Testanwendung:"""
        global tisch
        tisch=Tisch(70, 30, 120, 60, 0, 'red', True)
        
### ---------------------------------------------------
if __name__ == '__main__':
    app = TischApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
